%define stage1 1
Name:          rustc
Version:       1.84.1
Release:       1mamba
Summary:       The Rust programming language, designed to be a safe, concurrent, practical language
Group:         Applications/Development
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.rust-lang.org
Source:        https://static.rust-lang.org/dist/rustc-%{version}-src.tar.gz
License:       MIT
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libcurl-devel
BuildRequires: libgcc
BuildRequires: libgit2-devel
BuildRequires: libopenssl-devel
BuildRequires: libstdc++6-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
%if "%{stage1}" != "1"
BuildRequires: rustc
%endif
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description
The Rust programming language, designed to be a safe, concurrent, practical language.

%package -n lib%{name}
Group:         System/Libraries
Summary:       Shared libraries for %{name}

%description -n lib%{name}
This package contains shared libraries for %{name}.

%package apidocs
Group:         Documentation
Summary:       Documentation for %{name}

%description apidocs
This package contains the documentation for %{name}.


%prep
%setup -q -n %{name}-%{version}-src
#-D -T
#:<< _EOF

cat <<EOF > config.toml
profile = "user"
change-id = 123711

[llvm]
link-shared = true

[build]
%if "%{stage1}" != "1"
cargo = "/usr/bin/cargo"
rustc = "/usr/bin/rustc"
rustfmt = "/usr/bin/rustfmt"
%endif
locked-deps = true
vendor = true
extended = true
sanitizers = true
profiler = true
#build-stage = 2
#doc-stage = 2
#install-stage = 2
#test-stage = 2

[install]
prefix = "%{_prefix}"
libdir = "%{_lib}"
docdir = "share/doc/rust"

[rust]
# 0 or the new default of 16 is faster, but can result in worse performance
# https://github.com/rust-lang/rust/issues/47745
codegen-units = 1
codegen-units-std = 1
%ifarch %{ix86}
debuginfo-level = 0
debuginfo-level-std = 0
debug = false
%else
debuginfo-level = 1
debuginfo-level-std = 2
%endif
channel = "stable"
description = "openmamba %{name} %{epoch}:%{version}-%{release}"
rpath = false
frame-pointers = true
deny-warnings = false
backtrace-on-ice = true
remap-debuginfo = false
jemalloc = true
EOF

%build
#:<< _EOF
#./x.py build %{_smp_mflags}

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%ifarch %{ix86}
export CARGO_INCREMENTAL=1
%endif

DESTDIR=%{buildroot} ./x.py install %{_smp_mflags}

chmod +x %{buildroot}%{_libdir}/lib*.so*

cd %{buildroot}%{_libdir}
#rm rustlib/{components,manifest-rustc,rust-installer-version}
%ifarch %{ix86}
ln -sf rustlib/i686-unknown-linux-gnu/lib/*.so .
%else
%ifarch arm
ln -sf rustlib/arm-unknown-linux-gnueabi/lib/*.so .
%else
ln -sf rustlib/%{_arch}-unknown-linux-gnu/lib/*.so .
%endif
%endif
cd -

%find_lang %{name} || touch %{name}.lang

%clean
#[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"


%files
#-f %{name}.lang
%defattr(-,root,root)
%{_sysconfdir}/bash_completion.d/cargo
%{_bindir}/cargo*
%{_bindir}/clippy-driver*
%{_bindir}/rust*
%{_mandir}/man1/cargo-*.1*
%{_mandir}/man1/cargo.1*
%{_mandir}/man1/rustc.1*
%{_mandir}/man1/rustdoc.1*
%{_datadir}/zsh/site-functions/_cargo

%files -n lib%{name}
%defattr(-,root,root)
#%{_libdir}/rustlib/src/rust/Cargo.lock
%{_libdir}/libLLVM-*-rust-%{version}-stable.so*
%{_libdir}/libLLVM.so.*-rust-%{version}-stable
%{_libdir}/librustc*.so
%{_libdir}/libstd-*.so
%dir %{_libdir}/rustlib
%{_libdir}/rustlib/components
%{_libdir}/rustlib/rust-installer-version
%dir %{_libdir}/rustlib/etc
%{_libdir}/rustlib/etc/*
%{_libdir}/rustlib/install.log
%{_libdir}/rustlib/manifest-*
%dir %{_libdir}/rustlib/src
%dir %{_libdir}/rustlib/src/rust
%dir %{_libdir}/rustlib/src/rust/library
%{_libdir}/rustlib/src/rust/library/*
%dir %{_libdir}/rustlib/src/rust/src/llvm-project
%dir %{_libdir}/rustlib/src/rust/src/llvm-project/libunwind
%{_libdir}/rustlib/src/rust/src/llvm-project/libunwind/.clang-format
%{_libdir}/rustlib/src/rust/src/llvm-project/libunwind/*
%{_libdir}/rustlib/uninstall.sh
%ifarch %{ix86}
%dir %{_libdir}/rustlib/i686-unknown-linux-gnu
%{_libdir}/rustlib/i686-unknown-linux-gnu/*
%else
%ifarch arm
%dir %{_libdir}/rustlib/%{_arch}-unknown-linux-gnueabi
%{_libdir}/rustlib/%{_arch}-unknown-linux-gnueabi/*
%else
%dir %{_libdir}/rustlib/%{_arch}-unknown-linux-gnu
%{_libdir}/rustlib/%{_arch}-unknown-linux-gnu/*
%endif
%endif
%{_prefix}/libexec/rust-analyzer-proc-macro-srv

%files apidocs
%defattr(-,root,root)
%dir %{_datadir}/doc/rust
%{_datadir}/doc/rust/COPYRIGHT
%{_datadir}/doc/rust/LICENSE-*
%{_datadir}/doc/rust/README.md
%{_datadir}/doc/rust/README.md.old
%{_datadir}/doc/rust/html/.lock
%dir %{_datadir}/doc/rust/html
%{_datadir}/doc/rust/html/*
#%doc README.md

%changelog
* Sat Feb 01 2025 Automatic Build System <autodist@openmamba.org> 1.84.1-1mamba
- automatic version update by autodist

* Fri Jan 10 2025 Automatic Build System <autodist@openmamba.org> 1.84.0-1mamba
- automatic version update by autodist

* Sat Dec 21 2024 Automatic Build System <autodist@openmamba.org> 1.83.0-1mamba
- automatic version update by autodist

* Fri Oct 18 2024 Automatic Build System <autodist@openmamba.org> 1.82.0-1mamba
- automatic version update by autodist

* Fri Sep 06 2024 Automatic Build System <autodist@openmamba.org> 1.81.0-1mamba
- automatic version update by autodist

* Fri Aug 09 2024 Automatic Build System <autodist@openmamba.org> 1.80.1-1mamba
- automatic version update by autodist

* Thu Jul 25 2024 Automatic Build System <autodist@openmamba.org> 1.80.0-1mamba
- automatic version update by autodist

* Thu Jun 20 2024 Automatic Build System <autodist@openmamba.org> 1.79.0-1mamba
- automatic version update by autodist

* Thu May 02 2024 Automatic Build System <autodist@openmamba.org> 1.78.0-1mamba
- automatic version update by autodist

* Wed Apr 10 2024 Automatic Build System <autodist@openmamba.org> 1.77.2-1mamba
- automatic version update by autodist

* Fri Apr 05 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 1.77.1-2mamba
- rebuilt with profiler = true and sanitizers = true

* Thu Mar 28 2024 Automatic Build System <autodist@openmamba.org> 1.77.1-1mamba
- automatic version update by autodist

* Tue Mar 26 2024 Automatic Build System <autodist@openmamba.org> 1.77.0-1mamba
- automatic version update by autodist

* Sat Feb 10 2024 Automatic Build System <autodist@openmamba.org> 1.76.0-1mamba
- automatic version update by autodist

* Fri Dec 29 2023 Automatic Build System <autodist@mambasoft.it> 1.75.0-1mamba
- automatic version update by autodist

* Sat Dec 23 2023 Automatic Build System <autodist@mambasoft.it> 1.74.1-1mamba
- automatic version update by autodist

* Sat Oct 07 2023 Automatic Build System <autodist@mambasoft.it> 1.73.0-1mamba
- automatic version update by autodist

* Wed Sep 20 2023 Automatic Build System <autodist@mambasoft.it> 1.72.1-1mamba
- automatic version update by autodist

* Sun Sep 03 2023 Automatic Build System <autodist@mambasoft.it> 1.72.0-1mamba
- automatic version update by autodist

* Sun Aug 06 2023 Automatic Build System <autodist@mambasoft.it> 1.71.1-1mamba
- automatic version update by autodist

* Fri Jun 02 2023 Automatic Build System <autodist@mambasoft.it> 1.70.0-1mamba
- automatic version update by autodist

* Sat Apr 22 2023 Automatic Build System <autodist@mambasoft.it> 1.69.0-1mamba
- automatic version update by autodist

* Wed Mar 29 2023 Automatic Build System <autodist@mambasoft.it> 1.68.2-1mamba
- automatic version update by autodist

* Fri Mar 24 2023 Automatic Build System <autodist@mambasoft.it> 1.68.1-1mamba
- automatic version update by autodist

* Mon Mar 13 2023 Automatic Build System <autodist@mambasoft.it> 1.68.0-1mamba
- automatic version update by autodist

* Fri Feb 10 2023 Automatic Build System <autodist@mambasoft.it> 1.67.1-1mamba
- automatic version update by autodist

* Fri Jan 27 2023 Automatic Build System <autodist@mambasoft.it> 1.67.0-1mamba
- automatic version update by autodist

* Tue Nov 08 2022 Automatic Build System <autodist@mambasoft.it> 1.65.0-1mamba
- automatic version update by autodist

* Fri Sep 23 2022 Automatic Build System <autodist@mambasoft.it> 1.64.0-1mamba
- automatic version update by autodist

* Sat Aug 13 2022 Automatic Build System <autodist@mambasoft.it> 1.63.0-1mamba
- automatic version update by autodist

* Wed Jul 20 2022 Automatic Build System <autodist@mambasoft.it> 1.62.1-1mamba
- automatic version update by autodist

* Fri Jul 01 2022 Automatic Build System <autodist@mambasoft.it> 1.62.0-1mamba
- automatic version update by autodist

* Thu Jun 02 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 1.61.0-1mamba
- update to 1.61.0

* Fri Jan 21 2022 Automatic Build System <autodist@mambasoft.it> 1.58.1-1mamba
- automatic version update by autodist

* Thu Jan 13 2022 Automatic Build System <autodist@mambasoft.it> 1.58.0-1mamba
- automatic version update by autodist

* Fri Dec 03 2021 Automatic Build System <autodist@mambasoft.it> 1.57.0-1mamba
- automatic version update by autodist

* Tue Nov 02 2021 Automatic Build System <autodist@mambasoft.it> 1.56.1-1mamba
- automatic version update by autodist

* Wed Oct 27 2021 Automatic Build System <autodist@mambasoft.it> 1.56.0-1mamba
- automatic version update by autodist

* Sun Aug 15 2021 Automatic Build System <autodist@mambasoft.it> 1.54.0-1mamba
- automatic version update by autodist

* Tue May 11 2021 Automatic Build System <autodist@mambasoft.it> 1.52.1-1mamba
- automatic version update by autodist

* Sat Mar 27 2021 Automatic Build System <autodist@mambasoft.it> 1.51.0-1mamba
- automatic version update by autodist

* Sat Feb 27 2021 Automatic Build System <autodist@mambasoft.it> 1.50.0-1mamba
- automatic version update by autodist

* Tue Nov 10 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.47.0-1mamba
- update to 1.47.0

* Thu May 21 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.43.0-1mamba
- update to 1.43.0

* Thu Jul 05 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.27.0-1mamba
- update to 1.27.0

* Sat Jun 16 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.26.2-1mamba
- update to 1.26.2

* Mon Apr 09 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.25.0-1mamba
- package created using the webbuild interface
